#!/usr/bin/python
"""Implement hooks for thruk-agent charm."""

import sys

import actions

from charmhelpers.core import hookenv, host
from charmhelpers.core.services import helpers
from charmhelpers.core.services.base import ServiceManager

import thruk_helpers

config = hookenv.config()
hooks = hookenv.Hooks()


@hooks.hook("nrpe-external-master-relation-{joined,changed,broken,departed}")
@hooks.hook("thruk-agent-relation-{joined,changed,broken,departed}")
@hooks.hook("config-changed")
@hooks.hook("start")
@hooks.hook("stop")
def config_changed():
    """Handle config-changed hook."""
    manager = ServiceManager(
        [
            {
                "service": "thruk",
                "provided_data": [thruk_helpers.ThrukAgentRelation()],
                "required_data": [
                    thruk_helpers.thruk_info(),
                    thruk_helpers.CheckLivestatusSocket(),
                ],
                "data_ready": [
                    helpers.render_template(
                        source="thruk_local.conf", target="/etc/thruk/thruk_local.conf"
                    ),
                    actions.log_start,
                    actions.update_ppa,
                    actions.fix_livestatus_perms,
                    actions.thruk_set_password,
                    actions.notify_thrukmaster_relation,
                    actions.update_status,
                ],
            },
            {
                "service": "thruk-monitoring",
                "required_data": [
                    thruk_helpers.NEMRelation(),
                    helpers.RequiredConfig(),
                ],
                "data_ready": [
                    helpers.render_template(
                        source="thruk-nrpe.j2",
                        target="/etc/nagios/nrpe.d/check_{}.cfg".format(
                            hookenv.local_unit().replace("/", "-")
                        ),
                    ),
                    helpers.render_template(
                        source="thruk-nagios.j2",
                        target="/var/lib/nagios/export/service__{}-{}.cfg".format(
                            config["nagios_context"],
                            hookenv.local_unit().replace("/", "-"),
                        ),
                    ),
                ],
            },
        ]
    )
    manager.manage()


@hooks.hook("update-status")
def update_status():
    """Handle update-status hook."""
    # thruk can not start if livestatus is not enabled.
    if host.service_running("thruk"):
        hookenv.status_set("active", "ready")
    else:
        hookenv.status_set("blocked", '"thruk" service is not running.')
        # if nagios livestatus is not enabled CheckLivestatusSocket update
        # juju status message to suggest to the operator to enable it.
        if thruk_helpers.CheckLivestatusSocket():
            config_changed()


if __name__ == "__main__":
    try:
        hooks.execute(sys.argv)
    except hookenv.UnregisteredHookError as e:
        hookenv.log("Unknown hook {} - skipping.".format(e))
