#!/usr/bin/python
"""Define helper functions for thruk-agent charm."""

import hashlib
import os

from charmhelpers.core import hookenv
from charmhelpers.core.services import helpers


class ThrukAgentRelation(helpers.RelationContext):
    """
    Relation context for the `thruk-agent` interface.

    :param str name: Override the relation :attr:`name`, since it can vary from
                     charm to charm
    :param list additional_required_keys: Extend the list of
                                          :attr:`required_keys`
    """

    name = "thruk-agent"
    interface = "thruk-agent"

    @staticmethod
    def provide_data():
        """Provide data for thruk-agent relation."""
        keypath = "/var/lib/thruk/secret.key"
        with open(keypath) as keyfile:
            key = keyfile.read()
            thruk_key = key.rstrip("\n")

        m = hashlib.md5()
        m.update(hookenv.config("nagios_context"))
        thruk_id = m.hexdigest()
        host = hookenv.unit_get("private-address")
        url = "http://{}/".format(host)

        return {
            "url": url,
            "nagios_context": hookenv.config("nagios_context"),
            "thruk_key": thruk_key,
            "thruk_id": thruk_id,
        }


def thruk_info():
    """
    Create ThrukInfo instance from hookenv data.

    :returns A dict holding Thruk Info.
    """
    m = hashlib.md5()
    m.update(hookenv.config("nagios_context"))
    return {
        "nagios_context": hookenv.config("nagios_context"),
        "livestatus_path": hookenv.config("livestatus_path"),
        "thruk_id": m.hexdigest(),
    }


class CheckLivestatusSocket(dict):
    """An dict like object representing the socket status."""

    def __bool__(self):
        """Truthy if the socket isn't blocked."""
        if not os.path.exists(hookenv.config("livestatus_path")):
            hookenv.status_set(
                hookenv.WORKLOAD_STATES.BLOCKED, "nagios livestatus socket missing"
            )
            return False
        return True

    def __nonzero__(self):
        """Truthy if the socket isn't blocked."""
        return self.__bool__()


class NEMRelation(helpers.RelationContext):
    """Relation context for the NRPE external master."""

    name = "nrpe-external-master"
    interface = "nrpe-external-master"
    # required_keys = ['nagios_hostname']

    def get_data(self):
        """Provide data for the NRPE external master."""
        super(NEMRelation, self).get_data()
        if not hookenv.relation_ids(self.name):
            return
        self["nrpe_external_master"] = self[self.name]
